`xotl.tools.future`:mod: - Extend standard modules with "future" features
=========================================================================

.. module:: xotl.tools.future

Contents
--------

.. toctree::
   :maxdepth: 1
   :glob:

   future/*
